summaryrefslogtreecommitdiffhomepage
path: root/modules/luci-base/luasrc
diff options
context:
space:
mode:
Diffstat (limited to 'modules/luci-base/luasrc')
-rw-r--r--modules/luci-base/luasrc/http.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/luci-base/luasrc/http.lua b/modules/luci-base/luasrc/http.lua
index 16fb04c54..f4ede4b8a 100644
--- a/modules/luci-base/luasrc/http.lua
+++ b/modules/luci-base/luasrc/http.lua
@@ -14,7 +14,7 @@ local table, ipairs, pairs, type, tostring, tonumber, error =
module "luci.http"
-HTTP_MAX_CONTENT = 1024*8 -- 8 kB maximum content size
+HTTP_MAX_CONTENT = 1024*100 -- 100 kB maximum content size
context = util.threadlocal()
@@ -416,7 +416,7 @@ function mimedecode_message_body(src, msg, file_cb)
end
return true
- end)
+ end, HTTP_MAX_CONTENT)
return ltn12.pump.all(src, function (chunk)
len = len + (chunk and #chunk or 0)
@@ -460,7 +460,7 @@ function urldecode_message_body(src, msg)
end
return true
- end)
+ end, HTTP_MAX_CONTENT)
return ltn12.pump.all(src, function (chunk)
len = len + (chunk and #chunk or 0)